pub struct RepoConfig {
pub name: String,
pub i_own_this: bool,
pub source: RepoSourceConfig,
pub enabled: bool,
}Fields
name: Stringi_own_this: boolOperator attestation that they own this repo and consent to scanning.
The daemon refuses to ingest a repo without i_own_this = true.
source: RepoSourceConfigenabled: boolTrait Implementations
Sourceimpl Clone for RepoConfig
impl Clone for RepoConfig
Sourcefn clone(&self) -> RepoConfig
fn clone(&self) -> RepoConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RepoConfig
impl Debug for RepoConfig
Sourceimpl<'de> Deserialize<'de> for RepoConfig
impl<'de> Deserialize<'de> for RepoConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for RepoConfig
impl PartialEq for RepoConfig
Sourcefn eq(&self, other: &RepoConfig) -> bool
fn eq(&self, other: &RepoConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RepoConfig
impl Serialize for RepoConfig
impl Eq for RepoConfig
impl StructuralPartialEq for RepoConfig