pub struct ProjectIntegrationRecord {Show 13 fields
pub id: String,
pub project_id: String,
pub kind: ProjectIntegrationKind,
pub name: String,
pub enabled: bool,
pub events: Vec<ProjectIntegrationEvent>,
pub min_severity: Option<String>,
pub target: String,
pub created_at: i64,
pub updated_at: i64,
pub last_delivery_at: Option<i64>,
pub last_delivery_status: Option<String>,
pub last_delivery_error: Option<String>,
}Fields
id: Stringproject_id: Stringkind: ProjectIntegrationKindname: Stringenabled: boolevents: Vec<ProjectIntegrationEvent>min_severity: Option<String>target: Stringcreated_at: i64updated_at: i64last_delivery_at: Option<i64>last_delivery_status: Option<String>last_delivery_error: Option<String>Trait Implementations
Sourceimpl Clone for ProjectIntegrationRecord
impl Clone for ProjectIntegrationRecord
Sourcefn clone(&self) -> ProjectIntegrationRecord
fn clone(&self) -> ProjectIntegrationRecord
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProjectIntegrationRecord
impl Debug for ProjectIntegrationRecord
Sourceimpl<'de> Deserialize<'de> for ProjectIntegrationRecord
impl<'de> Deserialize<'de> for ProjectIntegrationRecord
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ProjectIntegrationRecord, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ProjectIntegrationRecord, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ProjectIntegrationRecord
impl PartialEq for ProjectIntegrationRecord
Sourcefn eq(&self, other: &ProjectIntegrationRecord) -> bool
fn eq(&self, other: &ProjectIntegrationRecord) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProjectIntegrationRecord
impl Serialize for ProjectIntegrationRecord
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl TS for ProjectIntegrationRecord
impl TS for ProjectIntegrationRecord
Sourcetype WithoutGenerics = ProjectIntegrationRecord
type WithoutGenerics = ProjectIntegrationRecord
If this type does not have generic parameters, then
The only requirement for these dummy types is that
WithoutGenerics should just be Self.
If the type does have generic parameters, then all generic parameters must be replaced with
a dummy type, e.g ts_rs::Dummy or (). The only requirement for these dummy types is that
EXPORT_TO must be None. Read moreSourcetype OptionInnerType = ProjectIntegrationRecord
type OptionInnerType = ProjectIntegrationRecord
If the implementing type is
std::option::Option<T>, then this associated type is set to T.
All other implementations of TS should set this type to Self instead.Sourcefn decl_concrete(cfg: &Config) -> String
fn decl_concrete(cfg: &Config) -> String
Declaration of this type using the supplied generic arguments.
The resulting TypeScript definition will not be generic. For that, see
TS::decl().
If this type is not generic, then this function is equivalent to TS::decl().Sourcefn decl(cfg: &Config) -> String
fn decl(cfg: &Config) -> String
Declaration of this type, e.g.
type User = { user_id: number, ... }.
This function will panic if the type has no declaration. Read moreSourcefn inline(cfg: &Config) -> String
fn inline(cfg: &Config) -> String
Formats this types definition in TypeScript, e.g
{ user_id: number }.
This function will panic if the type cannot be inlined.Sourcefn inline_flattened(cfg: &Config) -> String
fn inline_flattened(cfg: &Config) -> String
Flatten a type declaration.
This function will panic if the type cannot be flattened.
Sourcefn visit_generics(v: &mut impl TypeVisitor)where
ProjectIntegrationRecord: 'static,
fn visit_generics(v: &mut impl TypeVisitor)where
ProjectIntegrationRecord: 'static,
Iterates over all type parameters of this type.
Sourcefn output_path() -> Option<PathBuf>
fn output_path() -> Option<PathBuf>
Returns the output path to where
T should be exported, relative to the output directory.
The returned path does not include any base directory. Read moreSourcefn visit_dependencies(v: &mut impl TypeVisitor)where
ProjectIntegrationRecord: 'static,
fn visit_dependencies(v: &mut impl TypeVisitor)where
ProjectIntegrationRecord: 'static,
Iterates over all dependency of this type.
Sourcefn docs() -> Option<String>
fn docs() -> Option<String>
JSDoc comment to describe this type in TypeScript - when
TS is derived, docs are
automatically read from your doc comments or #[doc = ".."] attributesSourcefn dependencies(cfg: &Config) -> Vec<Dependency>where
Self: 'static,
fn dependencies(cfg: &Config) -> Vec<Dependency>where
Self: 'static,
Resolves all dependencies of this type recursively.
Sourcefn export(cfg: &Config) -> Result<(), ExportError>where
Self: 'static,
fn export(cfg: &Config) -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem.
To export this type together with all of its dependencies, use
TS::export_all. Read moreSourcefn export_all(cfg: &Config) -> Result<(), ExportError>where
Self: 'static,
fn export_all(cfg: &Config) -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem, together with all of its dependencies.
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_to_string(cfg: &Config) -> Result<String, ExportError>where
Self: 'static,
fn export_to_string(cfg: &Config) -> Result<String, ExportError>where
Self: 'static,
impl Eq for ProjectIntegrationRecord
impl StructuralPartialEq for ProjectIntegrationRecord