pub struct ProjectLaunchProfile {Show 18 fields
pub id: String,
pub project_id: String,
pub name: String,
pub mode: String,
pub build_steps: Vec<LaunchStep>,
pub start_steps: Vec<LaunchStep>,
pub seed_steps: Vec<LaunchStep>,
pub reset_steps: Vec<LaunchStep>,
pub login_steps: Vec<LaunchStep>,
pub stop_steps: Vec<LaunchStep>,
pub health_checks: Vec<LaunchHealthCheck>,
pub target_urls: Vec<String>,
pub env_refs: Vec<LaunchEnvRef>,
pub working_dirs: Vec<LaunchWorkingDir>,
pub readiness: String,
pub created_at: i64,
pub updated_at: i64,
pub is_default: bool,
}Fields
id: Stringproject_id: Stringname: Stringmode: Stringbuild_steps: Vec<LaunchStep>start_steps: Vec<LaunchStep>seed_steps: Vec<LaunchStep>reset_steps: Vec<LaunchStep>login_steps: Vec<LaunchStep>stop_steps: Vec<LaunchStep>health_checks: Vec<LaunchHealthCheck>target_urls: Vec<String>env_refs: Vec<LaunchEnvRef>working_dirs: Vec<LaunchWorkingDir>readiness: Stringcreated_at: i64updated_at: i64is_default: boolTrait Implementations
Sourceimpl Clone for ProjectLaunchProfile
impl Clone for ProjectLaunchProfile
Sourcefn clone(&self) -> ProjectLaunchProfile
fn clone(&self) -> ProjectLaunchProfile
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProjectLaunchProfile
impl Debug for ProjectLaunchProfile
Sourceimpl<'de> Deserialize<'de> for ProjectLaunchProfile
impl<'de> Deserialize<'de> for ProjectLaunchProfile
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ProjectLaunchProfile, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ProjectLaunchProfile, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ProjectLaunchProfile
impl PartialEq for ProjectLaunchProfile
Sourcefn eq(&self, other: &ProjectLaunchProfile) -> bool
fn eq(&self, other: &ProjectLaunchProfile) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProjectLaunchProfile
impl Serialize for ProjectLaunchProfile
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl TS for ProjectLaunchProfile
impl TS for ProjectLaunchProfile
Sourcetype WithoutGenerics = ProjectLaunchProfile
type WithoutGenerics = ProjectLaunchProfile
If this type does not have generic parameters, then
The only requirement for these dummy types is that
WithoutGenerics should just be Self.
If the type does have generic parameters, then all generic parameters must be replaced with
a dummy type, e.g ts_rs::Dummy or (). The only requirement for these dummy types is that
EXPORT_TO must be None. Read moreSourcetype OptionInnerType = ProjectLaunchProfile
type OptionInnerType = ProjectLaunchProfile
If the implementing type is
std::option::Option<T>, then this associated type is set to T.
All other implementations of TS should set this type to Self instead.Sourcefn decl_concrete(cfg: &Config) -> String
fn decl_concrete(cfg: &Config) -> String
Declaration of this type using the supplied generic arguments.
The resulting TypeScript definition will not be generic. For that, see
TS::decl().
If this type is not generic, then this function is equivalent to TS::decl().Sourcefn decl(cfg: &Config) -> String
fn decl(cfg: &Config) -> String
Declaration of this type, e.g.
type User = { user_id: number, ... }.
This function will panic if the type has no declaration. Read moreSourcefn inline(cfg: &Config) -> String
fn inline(cfg: &Config) -> String
Formats this types definition in TypeScript, e.g
{ user_id: number }.
This function will panic if the type cannot be inlined.Sourcefn inline_flattened(cfg: &Config) -> String
fn inline_flattened(cfg: &Config) -> String
Flatten a type declaration.
This function will panic if the type cannot be flattened.
Sourcefn visit_generics(v: &mut impl TypeVisitor)where
ProjectLaunchProfile: 'static,
fn visit_generics(v: &mut impl TypeVisitor)where
ProjectLaunchProfile: 'static,
Iterates over all type parameters of this type.
Sourcefn output_path() -> Option<PathBuf>
fn output_path() -> Option<PathBuf>
Returns the output path to where
T should be exported, relative to the output directory.
The returned path does not include any base directory. Read moreSourcefn visit_dependencies(v: &mut impl TypeVisitor)where
ProjectLaunchProfile: 'static,
fn visit_dependencies(v: &mut impl TypeVisitor)where
ProjectLaunchProfile: 'static,
Iterates over all dependency of this type.
Sourcefn docs() -> Option<String>
fn docs() -> Option<String>
JSDoc comment to describe this type in TypeScript - when
TS is derived, docs are
automatically read from your doc comments or #[doc = ".."] attributesSourcefn dependencies(cfg: &Config) -> Vec<Dependency>where
Self: 'static,
fn dependencies(cfg: &Config) -> Vec<Dependency>where
Self: 'static,
Resolves all dependencies of this type recursively.
Sourcefn export(cfg: &Config) -> Result<(), ExportError>where
Self: 'static,
fn export(cfg: &Config) -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem.
To export this type together with all of its dependencies, use
TS::export_all. Read moreSourcefn export_all(cfg: &Config) -> Result<(), ExportError>where
Self: 'static,
fn export_all(cfg: &Config) -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem, together with all of its dependencies.
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_to_string(cfg: &Config) -> Result<String, ExportError>where
Self: 'static,
fn export_to_string(cfg: &Config) -> Result<String, ExportError>where
Self: 'static,
impl Eq for ProjectLaunchProfile
impl StructuralPartialEq for ProjectLaunchProfile